# TaskThread

## Synopsis

Organize your complex asyncio python projects into hierarchical, intercommunicating "threads".

For documentation, click [here](https://elsampsa.github.io/task_thread)

*Proper documentation coming soon!*

## Installing

Development mode install:
```
git clone https://github.com/elsampsa/task_thread
cd task_thread
pip3 install --user --upgrade -e .
```

Or directly from the PyPi repo:
```
pip3 install --user task-virtualthread
```

## Authors
Sampsa Riikonen

## Copyright
(C) 2022 Sampsa Riikonen

## License
MIT
